package com.sun.org.apache.bcel.internal.classfile;

import java.io.IOException;
import java.io.DataOutputStream;

public class SimpleElementValue extends ElementValue
{
    private int index;
    
    public SimpleElementValue(int type, int index, ConstantPool cpool) {
        super(type, cpool);
        this.index = index;
    }
    
    public int getIndex() {
        return this.index;
    }
    
    public void setIndex(int index) {
        this.index = index;
    }
    
    public String getValueString() {
        if (super.getType() != 115) {
            throw new RuntimeException("Dont call getValueString() on a non STRING ElementValue");
        }
        ConstantUtf8 c = (ConstantUtf8)super.getConstantPool().getConstant(this.getIndex(), (byte)1);
        return c.getBytes();
    }
    
    public int getValueInt() {
        if (super.getType() != 73) {
            throw new RuntimeException("Dont call getValueString() on a non STRING ElementValue");
        }
        ConstantInteger c = (ConstantInteger)super.getConstantPool().getConstant(this.getIndex(), (byte)3);
        return c.getBytes();
    }
    
    public byte getValueByte() {
        if (super.getType() != 66) {
            throw new RuntimeException("Dont call getValueByte() on a non BYTE ElementValue");
        }
        ConstantInteger c = (ConstantInteger)super.getConstantPool().getConstant(this.getIndex(), (byte)3);
        return (byte)c.getBytes();
    }
    
    public char getValueChar() {
        if (super.getType() != 67) {
            throw new RuntimeException("Dont call getValueChar() on a non CHAR ElementValue");
        }
        ConstantInteger c = (ConstantInteger)super.getConstantPool().getConstant(this.getIndex(), (byte)3);
        return (char)c.getBytes();
    }
    
    public long getValueLong() {
        if (super.getType() != 74) {
            throw new RuntimeException("Dont call getValueLong() on a non LONG ElementValue");
        }
        ConstantLong j = (ConstantLong)super.getConstantPool().getConstant(this.getIndex());
        return j.getBytes();
    }
    
    public float getValueFloat() {
        if (super.getType() != 70) {
            throw new RuntimeException("Dont call getValueFloat() on a non FLOAT ElementValue");
        }
        ConstantFloat f = (ConstantFloat)super.getConstantPool().getConstant(this.getIndex());
        return f.getBytes();
    }
    
    public double getValueDouble() {
        if (super.getType() != 68) {
            throw new RuntimeException("Dont call getValueDouble() on a non DOUBLE ElementValue");
        }
        ConstantDouble d = (ConstantDouble)super.getConstantPool().getConstant(this.getIndex());
        return d.getBytes();
    }
    
    public boolean getValueBoolean() {
        if (super.getType() != 90) {
            throw new RuntimeException("Dont call getValueBoolean() on a non BOOLEAN ElementValue");
        }
        ConstantInteger bo = (ConstantInteger)super.getConstantPool().getConstant(this.getIndex());
        return bo.getBytes() != 0;
    }
    
    public short getValueShort() {
        if (super.getType() != 83) {
            throw new RuntimeException("Dont call getValueShort() on a non SHORT ElementValue");
        }
        ConstantInteger s = (ConstantInteger)super.getConstantPool().getConstant(this.getIndex());
        return (short)s.getBytes();
    }
    
    @Override
    public String toString() {
        return this.stringifyValue();
    }
    
    @Override
    public String stringifyValue() {
        ConstantPool cpool = super.getConstantPool();
        int _type = super.getType();
        switch (_type) {
            case 73: {
                ConstantInteger c = (ConstantInteger)cpool.getConstant(this.getIndex(), (byte)3);
                return Integer.toString(c.getBytes());
            }
            case 74: {
                ConstantLong j = (ConstantLong)cpool.getConstant(this.getIndex(), (byte)5);
                return Long.toString(j.getBytes());
            }
            case 68: {
                ConstantDouble d = (ConstantDouble)cpool.getConstant(this.getIndex(), (byte)6);
                return Double.toString(d.getBytes());
            }
            case 70: {
                ConstantFloat f = (ConstantFloat)cpool.getConstant(this.getIndex(), (byte)4);
                return Float.toString(f.getBytes());
            }
            case 83: {
                ConstantInteger s = (ConstantInteger)cpool.getConstant(this.getIndex(), (byte)3);
                return Integer.toString(s.getBytes());
            }
            case 66: {
                ConstantInteger b = (ConstantInteger)cpool.getConstant(this.getIndex(), (byte)3);
                return Integer.toString(b.getBytes());
            }
            case 67: {
                ConstantInteger ch = (ConstantInteger)cpool.getConstant(this.getIndex(), (byte)3);
                return String.valueOf((char)ch.getBytes());
            }
            case 90: {
                ConstantInteger bo = (ConstantInteger)cpool.getConstant(this.getIndex(), (byte)3);
                if (bo.getBytes() == 0) {
                    return "false";
                }
                return "true";
            }
            case 115: {
                ConstantUtf8 cu8 = (ConstantUtf8)cpool.getConstant(this.getIndex(), (byte)1);
                return cu8.getBytes();
            }
            default: {
                throw new RuntimeException("SimpleElementValue class does not know how to stringify type " + _type);
            }
        }
    }
    
    @Override
    public void dump(DataOutputStream dos) throws IOException {
        int _type = super.getType();
        dos.writeByte(_type);
        switch (_type) {
            case 66:
            case 67:
            case 68:
            case 70:
            case 73:
            case 74:
            case 83:
            case 90:
            case 115: {
                dos.writeShort(this.getIndex());
                return;
            }
            default: {
                throw new RuntimeException("SimpleElementValue doesnt know how to write out type " + _type);
            }
        }
    }
}
